FlowController class

Lightweight state controller for first-run step navigation.

Inheritance

Constructors

FlowController({required int stepCount})
Creates a controller with the provided total stepCount.

Properties

currentIndex int
Current zero-based step index.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isFirstStep bool
Whether the current step is the first step.
no setter
isLastStep bool
Whether the current step is the final step.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepCount int
Total number of steps in the flow.
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
back() → void
Moves to the previous step if possible.
dispose() → void
Discards any resources used by the object.
inherited
next() → void
Moves to the next step if possible.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
skip() → void
Jumps directly to the last step.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited