StorageService class
Safe wrapper around SharedPreferences used by first_run_kit.
Constructors
- StorageService({SharedPreferences? prefs})
- Creates a storage service.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBool(
String key) → Future< bool?> -
Reads a bool value by
key. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String key) → Future< bool> -
Removes a value by
key. -
safeClear(
) → Future< bool> - Clears all keys except the first-run flag.
-
setBool(
String key, bool value) → Future< bool> -
Stores a bool
valuebykey. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited