CustomStep class

A flow step that renders a custom widget supplied by the app.

Inheritance

Constructors

CustomStep({required Widget widget})
Creates a custom step.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type StepType
Type of the step used by the renderer.
finalinherited
widget Widget
Widget rendered for this step.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited