OnboardingStep class

A text/image onboarding page shown in the flow.

Inheritance

Constructors

OnboardingStep({required String title, required String description, Widget? image})
Creates an onboarding step.
const

Properties

description String
Body description for the onboarding screen.
final
hashCode int
The hash code for this object.
no setterinherited
image Widget?
Optional illustration widget.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Heading for the onboarding screen.
final
type StepType
Type of the step used by the renderer.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited