onNext method
void
onNext()
Goes to next step, or completes the flow on the last step.
Implementation
void onNext() {
if (controller.isLastStep) {
onComplete();
return;
}
controller.next();
}
Goes to next step, or completes the flow on the last step.
void onNext() {
if (controller.isLastStep) {
onComplete();
return;
}
controller.next();
}