CustomStep class
A flow step that renders a custom widget supplied by the app.
- Inheritance
-
- Object
- FirstRunStep
- CustomStep
Constructors
- CustomStep({required Widget widget})
-
Creates a custom step.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited