FirstRunFlowEvent class
Structured event payload for first-run flow analytics and logging.
Constructors
- FirstRunFlowEvent({required FirstRunFlowEventType type, required int stepIndex, required int totalSteps, required FirstRunStep step, required DateTime timestamp})
-
Creates a flow event.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- step → FirstRunStep
-
Step model active when event was emitted.
final
- stepIndex → int
-
Zero-based index of the active step when event was emitted.
final
- timestamp → DateTime
-
Event creation time.
final
- totalSteps → int
-
Total number of steps configured in the flow.
final
- type → FirstRunFlowEventType
-
Category of the emitted event.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited