PermissionStep class
A step that requests a runtime permission.
- Inheritance
-
- Object
- FirstRunStep
- PermissionStep
Constructors
- PermissionStep({required Permission permission, required String title, required String description, String? rationale, String requestButtonText = 'Allow'})
-
Creates a permission request step.
const
- PermissionStep.camera({String title = 'Camera Access', String description = 'Allow camera permission to scan and capture content.', String? rationale, String requestButtonText = 'Allow Camera'})
-
Convenience factory for camera permission.
factory
- PermissionStep.microphone({String title = 'Microphone Access', String description = 'Allow microphone permission for voice features.', String? rationale, String requestButtonText = 'Allow Microphone'})
-
Convenience factory for microphone permission.
factory
- PermissionStep.photos({String title = 'Photos Access', String description = 'Allow photos permission to import and save media.', String? rationale, String requestButtonText = 'Allow Photos'})
-
Convenience factory for photos permission.
factory
Properties
- description → String
-
Description of why permission is needed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- permission → Permission
-
Permission to request.
final
- rationale → String?
-
Optional extra rationale text shown to the user.
final
- requestButtonText → String
-
Label for the permission request button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Heading shown before requesting permission.
final
- type → StepType
-
Type of the step used by the renderer.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited