FirstRunActions class
Helper actions tied to FlowController.
Constructors
- FirstRunActions({required FlowController controller, required VoidCallback onComplete})
-
Creates helper actions.
const
Properties
- controller → FlowController
-
Controller used by the actions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onComplete → VoidCallback
-
Called when flow is completed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onNext(
) → void - Goes to next step, or completes the flow on the last step.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited