FirstRunConstants class
Constants used internally by first_run_kit.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultFirstRunValue → const bool
- Default value used when first-run state has not been written yet.
- firstRunKey → const String
- SharedPreferences key storing first-run completion state.